Index: /trunk/ippToPsps/jython/ipptopspsdb.py
===================================================================
--- /trunk/ippToPsps/jython/ipptopspsdb.py	(revision 33572)
+++ /trunk/ippToPsps/jython/ipptopspsdb.py	(revision 33573)
@@ -141,5 +141,5 @@
     want to load a test batch to PSPS
 
     We also check that these batches are more than 6 HOURs old, so that we don't attempt to 
     publish something simulataneously with the client that it producing it
     '''
@@ -154,5 +154,5 @@
                AND loaded_to_datastore != 1 \
                AND timestamp > '2011-10-27' \
-               AND timestamp < now() -  INTERVAL 6 HOUR"
+               AND timestamp < now() -  INTERVAL 12 HOUR"
 
         ids = []
@@ -507,5 +507,5 @@
 
     '''
     Is someone processing this item right now? Checks whether this was attempted within the last 6 HOUR
     '''
     def processingNow(self, batchType, stage_id):
@@ -517,5 +517,5 @@
                AND dvo_db = '" + self.config.dvoLabel + "' \
                AND batch_type != 'IN' \
-               AND timestamp BETWEEN now() - INTERVAL 6 HOUR AND now()"
+               AND timestamp BETWEEN now() - INTERVAL 12 HOUR AND now()"
 
         try:
@@ -141,5 +141,5 @@
     want to load a test batch to PSPS
 
-    We also check that these batches are more than 6 HOURs old, so that we don't attempt to 
+    We also check that these batches are more than 12 HOURs old, so that we don't attempt to 
     publish something simulataneously with the client that it producing it
     '''
@@ -507,5 +507,5 @@
 
     '''
-    Is someone processing this item right now? Checks whether this was attempted within the last 6 HOUR
+    Is someone processing this item right now? Checks whether this was attempted within the last 12 HOUR
     '''
     def processingNow(self, batchType, stage_id):
